@@ -4,9 +4,7 @@
 #include "global.h"
 #include "Info.hpp"
 
-namespace cURLpp
-{
-	
+
 template< >
 void
 cURLpp::InfoTypeConverter< std::string >::get(cURLpp::Easy &handle, 
@@ -26,15 +24,3 @@ cURLpp::InfoTypeConverter< std::list< std::string > >::get(cURLpp::Easy &,
 {
   
 }
-
-
-template< >
-void 
-cURLpp::InfoTypeConverter< long >::get(cURLpp::Easy &,
-			                                   CURLINFO ,
-						           long &)
-{
-  
-}
-
-}; /*namespace cURLpp */
